# libpythonpro
Módulo para exemplificar construção de projetos Python no curso Pytools

Nesse curso é ensinado como contribuir com projetos de código aberto. 

Suportada versão 3 de Python. 

Para instalar:
''' console 
python -m venv .venv 
ambiente virtural .venv\Scripts\activate
pip install requirements-dev.txt 
'''

Para verificar qualidade do código
''' console 
flake8
'''